@@ -50,6 +50,12 @@ StatsGridsOnSatsWidget::StatsGridsOnSatsWidget(DataProxy_SQLite *dp, QWidget *pa
     //prepareChart();
 }
 
+StatsGridsOnSatsWidget::~StatsGridsOnSatsWidget()
+{
+    delete(util);
+    delete(dataProxy);
+}
+
 void StatsGridsOnSatsWidget::createUI()
 {
     confirmedOnlyCheckBox->setText(tr("Show confirmed only"));
@@ -62,7 +68,8 @@ void StatsGridsOnSatsWidget::createUI()
     tableWidget->setColumnCount(7);
 
     tableWidget->resizeRowsToContents();
-    tableWidget->sortByColumn(2, Qt::AscendingOrder);
+    //tableWidget->sortByColumn(4, Qt::AscendingOrder);
+    //void QTableWidget::sortItems(int column, Qt::SortOrder order = Qt::AscendingOrder)
     tableWidget->horizontalHeader()->setStretchLastSection(true);
     //logView->sortByColumn(1, Qt::AscendingOrder);
 
@@ -175,6 +182,7 @@ void StatsGridsOnSatsWidget::prepareChart(const int _log)
         }
         numberLabel->setText(QString::number(number));
     }
+    tableWidget->sortItems(4, Qt::AscendingOrder);
 }
 
 void StatsGridsOnSatsWidget::slotConfirmedClicked()
