@@ -63,6 +63,7 @@ eLogQrzLog::eLogQrzLog(DataProxy_SQLite *dp, const QString &_parentFunction, con
 
 eLogQrzLog::~eLogQrzLog()
 {
+    delete(util);
     showDebugLog (Q_FUNC_INFO, "END");
 }
 
@@ -198,6 +199,33 @@ void eLogQrzLog::parseXMLAnswer(QXmlStreamReader &xml)
                 }
                 continue;
             }
+            else if (name == "Callsign")
+            { // TEMP
+                tdata = xml.readElementText();
+                if (tdata.length()>0)
+                {
+                   //qDebug() << Q_FUNC_INFO << " - CALLSIGN: " << tdata << QT_ENDL;
+                }
+                continue;
+            }
+            else if (name == "name")
+            { // TEMP
+                tdata = xml.readElementText();
+                if (tdata.length()>0)
+                {
+                    //qDebug() << Q_FUNC_INFO << " - Name: " << tdata << QT_ENDL;
+                }
+                continue;
+            }
+            else if (name == "country")
+            { // TEMP
+                tdata = xml.readElementText();
+                if (tdata.length()>0)
+                {
+                    //qDebug() << Q_FUNC_INFO << " - Country: " << tdata << QT_ENDL;
+                }
+                continue;
+            }
             else if (name == "Error")
             {
                 tdata = xml.readElementText();
@@ -223,7 +251,7 @@ void eLogQrzLog::parseXMLAnswer(QXmlStreamReader &xml)
                 if (tdata.length()>0)
                 {
                     emit dataFoundSignal("name", tdata);
-                    //qDebug() << Q_FUNC_INFO << " - Name: " << tdata << QT_ENDL;
+                    //qDebug() << Q_FUNC_INFO << " - FName: " << tdata << QT_ENDL;
                 }
                 continue;
             }
@@ -458,7 +486,7 @@ void eLogQrzLog::slotManagerFinished(QNetworkReply *data)
     }
     else
     {
-        sendSignal(result, qsos);
+        //sendSignal(result, qsos);
         //parseNetworkError(result);
     }
 
