@@ -66,7 +66,11 @@ MainWindowSatTab::MainWindowSatTab(DataProxy_SQLite *dp, QWidget *parent) :
        //qDebug() << "MainWindowSatTab::MainWindowSatTab - END"   << QT_ENDL;
 }
 
-MainWindowSatTab::~MainWindowSatTab(){}
+MainWindowSatTab::~MainWindowSatTab(){
+    delete(locator);
+    delete(util);
+    delete(dataProxy);
+}
 
 void MainWindowSatTab::createUI()
 {
@@ -341,6 +345,10 @@ void MainWindowSatTab::setSatName(const QString &_t)
      //TODO: Check that the format is OK
     //qDebug() << "MainWindowSatTab::setSatName: " << _t << QT_ENDL;
     //satNameLineEdit->setText(_t);
+    if (_t =="")
+    {
+        return;
+    }
     if (getSatIndex(_t) > 0)
     {
         setSatelliteCombo(_t);
