@@ -36,6 +36,7 @@ enum OnlineErrorCode {Ok, Fail};
 enum OnlineErrorReason {Other, Auth, DupeQSO, WrongLogBook};
 enum DebugLogLevel {Info, Debug};
 enum ValidFieldsForStats {DXCC, GridSquare};
+enum FilesToDownload {CTY, Sats};
 
 struct EntityData { // Used to pass a list of data from World to dxccstatuswidget
   int dxcc;
@@ -50,6 +51,12 @@ struct EntityBandStatus { // Used to pass a list of data from Awards to dxccstat
   bool confirmed;
 };
 
+
+struct Coordinate {
+    double lat;
+    double lon;
+};
+
 #if (QT_VERSION >= QT_VERSION_CHECK(5, 15, 2))
 #define QT_SKIP Qt::SkipEmptyParts
 #define QT_ENDL Qt::endl
