@@ -93,6 +93,7 @@ void QSO::clear()
     qso_dateTime = QDateTime();
     lotwUpdating = false;
     realTime = false;
+    manualMode = false;
 
     comment = QString();
     satName = QString();
@@ -330,6 +331,16 @@ bool QSO::getRealTime()
     return realTime;
 }
 
+void QSO::setManualMode(const bool _rt)
+{
+    manualMode = _rt;
+}
+
+bool QSO::getManualMode()
+{
+    return manualMode;
+}
+
 
 double QSO::setFreqTX(const double _f)
 {
@@ -750,6 +761,29 @@ void QSO::setLoTWUpdating(bool _lotw)
     lotwUpdating = _lotw;
 }
 
+void QSO::setDefaultEQSLSentServices(const bool _send)
+{
+    if (_send)
+    {
+        if ((getLoTWQSL_SENT()).isEmpty())
+        {
+            setLoTWQSL_SENT ("Q");
+        }
+        if ((getClubLogStatus ()).isEmpty())
+        {
+            setClubLogStatus ("M");
+        }
+        if ((getEQSLQSL_SENT ()).isEmpty())
+        {
+            setEQSLQSL_SENT ("Q");
+        }
+        if ((getQRZCOMStatus ()).isEmpty())
+        {
+            setQRZCOMStatus ("M");
+        }
+    }
+}
+
 bool QSO::setGridSquare(const QString &_c)
 {
     //qDebug() << Q_FUNC_INFO << ": " << _c;
