@@ -113,7 +113,7 @@ signals:
                      const QString &comment, const QString &stationcallsign, const QString &name,
                      const QString &_operator, const QDateTime datetime, const QDateTime datetime_off,
                      const QString &_exchangeTX, const QString &_exchangeRX, const QString &_txpwr);
-    void clearSignal();
+    void clearSignal(QString _func);
 
 private slots:
     void slotReadPendingDatagrams();
